diff --git a/debian/changelog b/debian/changelog
index 7c7a4c72f9c1bf744617c5e3b1f009b8e94c7b42..76d1ba6cb835fe07d69677e94c28127a688a6f5d 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,37 +1,39 @@
-dcpman (0.1.2~2.gbp1e5230) UNRELEASED; urgency=medium
-
-  [ Nimrod Adar ]
-  ** SNAPSHOT build @1e523033e4cf94509378a806d2ac9cf5dae38b76 **
-
-  * Adding better detection of encrypted DCPs by using avprobe to try and read the mxf files (still not 100% correct).
-  * UNRELEASED
+dcpman (0.1.3) UNRELEASED; urgency=medium
 
   [ Adar Nimrod ]
   * Create debian changelog from git commits when building.
+  * Better cleaning and publishing using Fabric.
+  * Improved clean.
+  * Added output to log file on every verification.
+  * Revert "Added output to log file on every verification."
+  * Work on future feature (full ingest of DCP from removable media).
+  * Improved clean.
+  * 	modified:   fabfile.py
+  * Added output to log file on every verification.
+  * Revert "Added output to log file on every verification."
+  * Work on future feature (full ingest of DCP from removable media).
 
   [ Nimrod Adar ]
 
   [ Adar Nimrod ]
-  * Create debian changelog from git commits when building.
+  * Improved clean.
+  * 	modified:   fabfile.py
+  * Added output to log file on every verification.
+  * Revert "Added output to log file on every verification."
+  * Work on future feature (full ingest of DCP from removable media).
 
   [ Nimrod Adar ]
 
   [ Adar Nimrod ]
-  * Create debian changelog from git commits when building.
-
-  [ Nimrod Adar ]
-
-  [ Adar Nimrod ]
-  * Create debian changelog from git commits when building.
-
-  [ Nimrod Adar ]
-
-  [ Adar Nimrod ]
-  * Create debian changelog from git commits when building.
+  * Improved clean.
+  * 	modified:   fabfile.py
+  * Added output to log file on every verification.
+  * Revert "Added output to log file on every verification."
+  * Work on future feature (full ingest of DCP from removable media).
 
   [ Nimrod Adar ]
 
- -- Nimrod Adar <nimrod@nimrod.private>  Wed, 27 Aug 2014 15:37:46 +0300
+ -- Nimrod Adar <nimrod@nimrod.private>  Tue, 16 Sep 2014 11:01:49 +0300
 
 dcpman (0.1) UNRELEASED; urgency=medium
 
diff --git a/source/manager.py b/source/manager.py
index db37f276fcbf1410d5fa39d6e07c3ae598d1904f..f748bb46e9b9a83baab084089101b2a1432a99fe 100755
--- a/source/manager.py
+++ b/source/manager.py
@@ -1,11 +1,16 @@
 #!/usr/bin/env python3
 from PyQt4 import QtGui
 from PyQt4 import QtCore
-#from dcpman.dcp import DCP
-#from dcpman import ui #autogenerated file from Qt Designer to setup the window
-from dcp import DCP
-import ui
+try:
+    from dcpman.dcp import DCP
+except:
+    from dcp import DCP
+try:
+    from dcpman import ui #autogenerated file from Qt Designer to setup the window
+except:
+    import ui
 import sys
+from os.path import basename
 import syslog
 import time
 
@@ -22,12 +27,12 @@ class verifyThread(QtCore.QThread):
             result = dcp.verify()
             if result:
                 window.verifyLine.setText('OK')
-                syslog.syslog (syslog.LOG_INFO, time.ctime () + dcp.name +\
-                        ' verification succeeded.')
+                syslog.syslog (syslog.LOG_INFO, time.ctime () +\
+                        directoryname + ' verification succeeded.')
             else:
                 window.verifyLine.setText('Corrupted!')
-                syslog.syslog (syslog.LOG_INFO, time.ctime () + dcp.name +\
-                        ' verification failed.')
+                syslog.syslog (syslog.LOG_INFO, time.ctime () +\
+                        directoryname + ' verification failed.')
         except BaseException as exception:
             window.verifyLine.setText(str(exception))
 
@@ -50,6 +55,7 @@ if __name__ == '__main__':
     app.setWindowIcon(icon)
     directory = QtGui.QFileDialog.getExistingDirectory( \
             caption='Please select the location of the DCP')
+    directoryname = basename (directory)
     mainwindow = QtGui.QMainWindow()
     window = ui.Ui_MainWindow()
     window.setupUi(mainwindow)
@@ -58,18 +64,20 @@ if __name__ == '__main__':
         dcp = DCP(directory)
         try:
             window.nameLine.setText(dcp.name)
-            syslog.syslog (syslog.INFO, time.ctime () + dcp.name +\
-                    'parsed.')
+            syslog.syslog (syslog.LOG_INFO, time.ctime () + directoryname +\
+                    ' parsed.')
         except AttributeError:
-            window.nameLine.setText(directory.split('/')[-1])
+            window.nameLine.setText (basename (directory))
+            syslog.syslog (syslog.LOG_INFO, time.ctime () + directoryname +\
+                    ' parsed.')
         if dcp.signed:
              syslog.syslog (syslog.INFO, time.ctime () + dcp.name +\
                      ' is signed.')
         else:
             syslog.syslog (syslog.INFO, time.ctime () + dcp.name +\
                     ' is not sigend.')
-        syslog.syslog (syslog.INFO, time.ctime () + dcp.name +\
-                ' duration is ' + dcp.duration)
+        syslog.syslog (syslog.LOG_INFO, time.ctime () + directoryname +\
+                ' duration is ' + str (dcp.duration))
         if dcp.signed and dcp.duration == 0:
             window.encryptedLine.setText('Most likely')
         elif dcp.signed or dcp.duration == 0:
@@ -58,18 +64,20 @@ if __name__ == '__main__':
         if dcp.signed:
-             syslog.syslog (syslog.INFO, time.ctime () + dcp.name +\
+             syslog.syslog (syslog.LOG_INFO, time.ctime () + directoryname +\
                      ' is signed.')
         else:
@@ -58,18 +64,20 @@ if __name__ == '__main__':
                      ' is signed.')
         else:
-            syslog.syslog (syslog.INFO, time.ctime () + dcp.name +\
+            syslog.syslog (syslog.LOG_INFO, time.ctime () + directoryname +\
                     ' is not sigend.')